diff --git a/arch/arm64/boot/dts/qcom/pm6125.dtsi b/arch/arm64/boot/dts/qcom/pm6125.dtsi
new file mode 100644
index 000000000000..fed438c50c1f
--- /dev/null
+++ b/arch/arm64/boot/dts/qcom/pm6125.dtsi
@@ -0,0 +1,25 @@
+// #include <dt-bindings/input/input.h>
+// #include <dt-bindings/input/qcom,qpnp-power-on.h>
+// #include <dt-bindings/interrupt-controller/irq.h>
+#include <dt-bindings/spmi/spmi.h>
+// #include <dt-bindings/iio/qcom,spmi-vadc.h>
+
+&spmi_bus {
+	qcom,pm6125@0 {
+		compatible = "qcom,spmi-pmic";
+		reg = <0x0 SPMI_USID>;
+		#address-cells = <2>;
+		#size-cells = <0>;
+	};
+
+	qcom,pm6125@1 {
+		compatible ="qcom,spmi-pmic";
+		reg = <0x1 SPMI_USID>;
+		#address-cells = <2>;
+		#size-cells = <0>;
+
+		pm6125_spmi_regulators: pm6125-regulators {
+			compatible = "qcom,pm6125-regulators";
+		};
+	};
+};
diff --git a/arch/arm64/boot/dts/qcom/sm4250-oneplus-billie2.dts b/arch/arm64/boot/dts/qcom/sm4250-oneplus-billie2.dts
index 79ed244e99b4..b8f478f4404e 100644
--- a/arch/arm64/boot/dts/qcom/sm4250-oneplus-billie2.dts
+++ b/arch/arm64/boot/dts/qcom/sm4250-oneplus-billie2.dts
@@ -6,6 +6,7 @@
 /dts-v1/;
 
 #include "sm4250.dtsi"
+#include "pm6125.dtsi"
 
 / {
 	model = "OnePlus Nord N100";
diff --git a/arch/arm64/boot/dts/qcom/sm4250.dtsi b/arch/arm64/boot/dts/qcom/sm4250.dtsi
index 8ea213288b49..af292f2a6715 100644
--- a/arch/arm64/boot/dts/qcom/sm4250.dtsi
+++ b/arch/arm64/boot/dts/qcom/sm4250.dtsi
@@ -882,6 +882,25 @@ ufs_mem_phy_lanes: lanes@4807400 {
 			};
 		};
 
+		spmi_bus: qcom,spmi@1c40000 {
+			compatible = "qcom,spmi-pmic-arb";
+			reg = <0x1c40000 0x1100>,
+				<0x1e00000 0x2000000>,
+				<0x3e00000 0x100000>,
+				<0x3f00000 0xa0000>,
+				<0x1c0a000 0x26000>;
+			reg-names = "core", "chnls", "obsrvr", "intr", "cnfg";
+			interrupt-names = "periph_irq";
+			interrupts = <GIC_SPI 183 IRQ_TYPE_LEVEL_HIGH>;
+			qcom,ee = <0>;
+			qcom,channel = <0>;
+			#address-cells = <2>;
+			#size-cells = <0>;
+			interrupt-controller;
+			#interrupt-cells = <4>;
+			cell-index = <0>;
+		};
+
 		rpm_msg_ram: memory@45f0000 {
 			compatible = "qcom,rpm-msg-ram";
 			reg = <0x45f0000 0x7000>;
diff --git a/drivers/regulator/qcom_spmi-regulator.c b/drivers/regulator/qcom_spmi-regulator.c
index e62e1d72d943..52d18a00ff44 100644
--- a/drivers/regulator/qcom_spmi-regulator.c
+++ b/drivers/regulator/qcom_spmi-regulator.c
@@ -1568,6 +1568,8 @@ static int spmi_regulator_match(struct spmi_regulator *vreg, u16 force_type)
 					  SPMI_COMMON_REG_DIG_MAJOR_REV];
 		subtype		= version[SPMI_COMMON_REG_SUBTYPE -
 					  SPMI_COMMON_REG_DIG_MAJOR_REV];
+		dev_info(vreg->dev, "name %s, type 0x%x, sub 0x%x, rev %u\n",
+				vreg->desc.name, (u32) type, (u32) subtype, dig_major_rev);
 	} else {
 		type = force_type >> 8;
 		subtype = force_type;
@@ -1848,6 +1850,34 @@ static int spmi_regulator_of_parse(struct device_node *node,
 	return 0;
 }
 
+static const struct spmi_regulator_data pm6125_regulators[] = {
+	{ "s6", 0x2300, "vdd_s6" },
+	{ "s7", 0x2600, "vdd_s7" },
+	{ "s8", 0x2900, "vdd_s8" },
+	{ "l1", 0x4000, "vdd_l1" },
+	{ "l4", 0x4300, "vdd_l4" },
+	{ "l5", 0x4400, "vdd_l5" },
+	{ "l6", 0x4500, "vdd_l6" },
+	{ "l7", 0x4600, "vdd_l7" },
+	{ "l8", 0x4700, "vdd_l8" },
+	{ "l9", 0x4800, "vdd_l9" },
+	{ "l10", 0x4900, "vdd_l10" },
+	{ "l11", 0x4a00, "vdd_l11" },
+	{ "l12", 0x4b00, "vdd_l12" },
+	{ "l13", 0x4c00, "vdd_l13" },
+	{ "l14", 0x4d00, "vdd_l14" },
+	{ "l15", 0x4e00, "vdd_l15" },
+	{ "l16", 0x4f00, "vdd_l16" },
+	{ "l17", 0x5000, "vdd_l17" },
+	{ "l18", 0x5100, "vdd_l18" },
+	{ "l19", 0x5200, "vdd_l19" },
+	{ "l20", 0x5300, "vdd_l20" },
+	{ "l21", 0x5400, "vdd_l21" },
+	{ "l22", 0x5500, "vdd_l22" },
+	{ "l23", 0x5600, "vdd_l23" },
+	{ "l24", 0x5700, "vdd_l24" },
+};
+
 static const struct spmi_regulator_data pm8941_regulators[] = {
 	{ "s1", 0x1400, "vdd_s1", },
 	{ "s2", 0x1700, "vdd_s2", },
@@ -2083,6 +2113,7 @@ static const struct spmi_regulator_data pms405_regulators[] = {
 };
 
 static const struct of_device_id qcom_spmi_regulator_match[] = {
+	{ .compatible = "qcom,pm6125-regulators", .data = &pm6125_regulators },
 	{ .compatible = "qcom,pm8004-regulators", .data = &pm8004_regulators },
 	{ .compatible = "qcom,pm8005-regulators", .data = &pm8005_regulators },
 	{ .compatible = "qcom,pm8841-regulators", .data = &pm8841_regulators },
